@@ -1,14 +1,14 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use warnings;
 use strict;
 
 package Log::Report::Extract::PerlPPI;
 use vars '$VERSION';
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 use base 'Log::Report::Extract';
 
@@ -79,7 +79,8 @@ sub process($@)
                : $dom->isa('PPI::Token::QuoteLike::Words') ? ($dom->literal)[0]
                : undef;
 
-            $self->_reset($domain, $fn);
+            $self->_reset($domain, $fn)
+                if defined $domain;
         }
 
         $node->find_any( sub {
